import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _extends from "@babel/runtime/helpers/esm/extends";
import { unstable_composeClasses as composeClasses } from '@material-ui/unstyled';
import { deepmerge } from '@material-ui/utils';
import clsx from 'clsx';
import PropTypes from 'prop-types';
import * as React from 'react';
import experimentalStyled from '../styles/experimentalStyled';
import useThemeProps from '../styles/useThemeProps';
import capitalize from '../utils/capitalize';
import imageListItemBarClasses, { getImageListItemBarUtilityClass } from './imageListItemBarClasses';

var overridesResolver = function overridesResolver(props, styles) {
  var _extends2;

  var styleProps = props.styleProps;
  return deepmerge(styles.root || {}, _extends({}, styles["position".concat(capitalize(styleProps.position))], (_extends2 = {}, _defineProperty(_extends2, "& .".concat(imageListItemBarClasses.titleWrap), _extends({}, styles.titleWrap, styles["titleWrap".concat(capitalize(styleProps.position))], styleProps.actionIcon && styles["titleWrapActionPos".concat(capitalize(styleProps.actionPosition))])), _defineProperty(_extends2, "& .".concat(imageListItemBarClasses.title), styles.title), _defineProperty(_extends2, "& .".concat(imageListItemBarClasses.subtitle), styles.subtitle), _defineProperty(_extends2, "& .".concat(imageListItemBarClasses.actionIcon), _extends({}, styles.actionIcon, styles["actionIconActionPos".concat(capitalize(styleProps.actionPosition))])), _extends2)));
};

var useUtilityClasses = function useUtilityClasses(styleProps) {
  var classes = styleProps.classes,
      position = styleProps.position,
      actionIcon = styleProps.actionIcon,
      actionPosition = styleProps.actionPosition;
  var slots = {
    root: ['root', "position".concat(capitalize(position))],
    titleWrap: ['titleWrap', "titleWrap".concat(capitalize(position)), actionIcon && "titleWrapActionPos".concat(capitalize(actionPosition))],
    title: ['title'],
    subtitle: ['subtitle'],
    actionIcon: ['actionIcon', "actionIconActionPos".concat(capitalize(actionPosition))]
  };
  return composeClasses(slots, getImageListItemBarUtilityClass, classes);
};

var ImageListItemBarRoot = experimentalStyled('div', {}, {
  name: 'MuiImageListItemBar',
  slot: 'Root',
  overridesResolver: overridesResolver
})(function (_ref) {
  var theme = _ref.theme,
      styleProps = _ref.styleProps;
  return _extends({
    /* Styles applied to the root element. */
    position: 'absolute',
    left: 0,
    right: 0,
    background: 'rgba(0, 0, 0, 0.5)',
    display: 'flex',
    alignItems: 'center',
    fontFamily: theme.typography.fontFamily
  }, styleProps.position === 'bottom' && {
    bottom: 0
  }, styleProps.position === 'top' && {
    top: 0
  }, styleProps.position === 'below' && {
    position: 'relative',
    background: 'transparent',
    alignItems: 'normal'
  });
});
var ImageListItemBarTitleWrap = experimentalStyled('div', {}, {
  name: 'MuiImageListItemBar',
  slot: 'TitleWrap'
})(function (_ref2) {
  var theme = _ref2.theme,
      styleProps = _ref2.styleProps;
  return _extends({
    /* Styles applied to the title and subtitle container element. */
    flexGrow: 1,
    padding: '12px 16px',
    color: theme.palette.common.white,
    overflow: 'hidden'
  }, styleProps.position === 'below' && {
    padding: '6px 0 12px',
    color: 'inherit'
  }, styleProps.actionIcon && styleProps.actionPosition === 'left' && {
    paddingLeft: 0
  }, styleProps.actionIcon && styleProps.actionPosition === 'right' && {
    paddingRight: 0
  });
});
var ImageListItemBarTitle = experimentalStyled('div', {}, {
  name: 'MuiImageListItemBar',
  slot: 'Title'
})(function (_ref3) {
  var theme = _ref3.theme;
  return {
    /* Styles applied to the title container element. */
    fontSize: theme.typography.pxToRem(16),
    lineHeight: '24px',
    textOverflow: 'ellipsis',
    overflow: 'hidden',
    whiteSpace: 'nowrap'
  };
});
var ImageListItemBarSubtitle = experimentalStyled('div', {}, {
  name: 'MuiImageListItemBar',
  slot: 'Subtitle'
})(function (_ref4) {
  var theme = _ref4.theme;
  return {
    /* Styles applied to the subtitle container element. */
    fontSize: theme.typography.pxToRem(12),
    lineHeight: 1,
    textOverflow: 'ellipsis',
    overflow: 'hidden',
    whiteSpace: 'nowrap'
  };
});
var ImageListItemBarActionIcon = experimentalStyled('div', {}, {
  name: 'MuiImageListItemBar',
  slot: 'ActionIcon'
})(function (_ref5) {
  var styleProps = _ref5.styleProps;
  return _extends({}, styleProps.actionPosition === 'left' && {
    order: -1
  });
});
var ImageListItemBar = /*#__PURE__*/React.forwardRef(function ImageListItemBar(inProps, ref) {
  var props = useThemeProps({
    props: inProps,
    name: 'MuiImageListItemBar'
  });

  var actionIcon = props.actionIcon,
      _props$actionPosition = props.actionPosition,
      actionPosition = _props$actionPosition === void 0 ? 'right' : _props$actionPosition,
      className = props.className,
      subtitle = props.subtitle,
      title = props.title,
      _props$position = props.position,
      position = _props$position === void 0 ? 'bottom' : _props$position,
      other = _objectWithoutProperties(props, ["actionIcon", "actionPosition", "className", "subtitle", "title", "position"]);

  var styleProps = _extends({}, props, {
    position: position,
    actionPosition: actionPosition
  });

  var classes = useUtilityClasses(styleProps);
  return /*#__PURE__*/React.createElement(ImageListItemBarRoot, _extends({
    styleProps: styleProps,
    className: clsx(classes.root, className),
    ref: ref
  }, other), /*#__PURE__*/React.createElement(ImageListItemBarTitleWrap, {
    styleProps: styleProps,
    className: classes.titleWrap
  }, /*#__PURE__*/React.createElement(ImageListItemBarTitle, {
    className: classes.title
  }, title), subtitle ? /*#__PURE__*/React.createElement(ImageListItemBarSubtitle, {
    className: classes.subtitle
  }, subtitle) : null), actionIcon ? /*#__PURE__*/React.createElement(ImageListItemBarActionIcon, {
    styleProps: styleProps,
    className: classes.actionIcon
  }, actionIcon) : null);
});
process.env.NODE_ENV !== "production" ? ImageListItemBar.propTypes = {
  // ----------------------------- Warning --------------------------------
  // | These PropTypes are generated from the TypeScript type definitions |
  // |     To update them edit the d.ts file and run "yarn proptypes"     |
  // ----------------------------------------------------------------------

  /**
   * An IconButton element to be used as secondary action target
   * (primary action target is the item itself).
   */
  actionIcon: PropTypes.node,

  /**
   * Position of secondary action IconButton.
   * @default 'right'
   */
  actionPosition: PropTypes.oneOf(['left', 'right']),

  /**
   * @ignore
   */
  children: PropTypes.node,

  /**
   * Override or extend the styles applied to the component.
   */
  classes: PropTypes.object,

  /**
   * @ignore
   */
  className: PropTypes.string,

  /**
   * Position of the title bar.
   * @default 'bottom'
   */
  position: PropTypes.oneOf(['below', 'bottom', 'top']),

  /**
   * String or element serving as subtitle (support text).
   */
  subtitle: PropTypes.node,

  /**
   * The system prop that allows defining system overrides as well as additional CSS styles.
   */
  sx: PropTypes.object,

  /**
   * Title to be displayed.
   */
  title: PropTypes.node
} : void 0;
export default ImageListItemBar;